/**
  *  \file client/dialogs/simplemboxdlg.cc
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/simplemboxdlg.h"
#include "client/widgets/helpwidget.h"
#include "client/widgets/msgdisplay.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/prefix.h"
#include "ui/widgets/button.h"
#include "ui/widgets/quit.h"
#include "util/nls.h"
#include "client/widgets/msgaction.h"

namespace {
    class WNullMessageActionPanel : public WMessageActionPanel {
     public:
        WNullMessageActionPanel(GMessagebox& mbox)
            : WMessageActionPanel(mbox)
            { }
        virtual void updateMessageControls()
            { }
    };
}

WSimpleMailboxWindow::WSimpleMailboxWindow(string_t title, GMessagebox& mbox)
    : UIWindow(title, BLUE_WINDOW, COLOR_BLACK)
{
    init(mbox);
}

void
WSimpleMailboxWindow::init(GMessagebox& mbox)
{
    //  HBox
    //    VBox
    //      WNullMessageActionPanel
    //      HBox
    //        UIButton "Close"
    //        UIButton "Help"
    //        UISpacer
    //    WMessageDisplay

    setLayout(UIHBoxLayout::instance5);

    UIGroup& g1  = h.add(new UIGroup(UIVBoxLayout::instance5));
    add(g1);
    add(h.add(new WMessageDisplay(0, mbox)));

    UIGroup& g12 = h.add(new UIGroup(UIHBoxLayout::instance5));
    g1.add(h.add(new WNullMessageActionPanel(mbox)));
    g1.add(g12);
    
    g12.add(h.add(new UIButton(1, _("Close"), SDLK_ESCAPE)).addStop());
    g12.add(h.add(new UIButton(_("Help"), 'h')));
    g12.add(h.add(new UISpacer()));

    add(h.add(new UIPrefixArg()));
    add(h.add(new WHelpWidget("pcc2:msgin")));
    add(h.add(new UIQuit(1)));

    pack();
}
