/**
  *  \file game/fleetfc.h
  *  \brief Class GFleetFCodeChanger
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_FLEETFC_H
#define PCC_V2_GAME_FLEETFC_H

#include <vector>
#include "cpluslib/string.h"

class GGameTurn;

/** Helper for changing a fleet's friendly code. */
class GFleetFCodeChanger {
 public:
    GFleetFCodeChanger(GGameTurn& trn, int fleet_id);
    ~GFleetFCodeChanger();

    void setFCode(string_t fcode);
    void unsetFCode(string_t avoid);
    void undo();

 private:
    GGameTurn& trn;
    const int fleet_id;

    /** Information about a ship. */
    struct Info {
        /** Ship Id. */
        int sid;
        /** Old friendly code. Code that was active before this object was constructed. */
        string_t old_fcode;
        /** Random friendly code. Precomputed so that unsetFCode always has the same
            result, no matter how often it's called. */
        string_t random_fcode;
        /** Constructor for convenience. */
        Info(int sid, string_t old, string_t rand)
            : sid(sid), old_fcode(old), random_fcode(rand)
            { }
    };
    std::vector<Info> info;

    void init();
};

#endif
