/**
  *  \file game/undo.h
  *  \brief Undo Validation for Planets
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_UNDO_H
#define PCC_V2_GAME_UNDO_H

#include "game/spec.h"

class GGameTurn;

/** Undo information for a place in space. This computes and contains
    information about the following items:
    - supplies that can be bought (=un-sold)
    - ammunition that can be sold (=un-built)
    - tech levels that can be sold (=un-bought)

    Since only planets can produce or convert cargo, this only works
    on planets and ships in orbit. It does not work on ships in space.

    Other things that could be undone but need less fancier
    arbitration:
    - planetary structures and base defense, can always be sold down
      to the level of previous turn
    - starship components, can always be sold down to the level
      of previous turn, but make sure build order is not violated */
class GUndoInformation {
    int32_t torps_to_sell[NUM_TORPS];
    int32_t fighters_to_sell;
    int32_t supplies_to_buy;
    int minimum_tech_levels[4];
 public:
    GUndoInformation();
    void computeInformation(const GGameTurn& trn, int pid);
    void clear();

    int32_t getAmmoAllowedToSell(GCargoType type) const;
    int32_t getSuppliesAllowedToBuy() const;
    int     getMinimumTech(TTechLevel level) const;
};

#endif
