/**
  *  \file int/export/exptext.h
  *  \brief Export to Text File
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_EXPORT_EXPTEXT_H
#define PCC_V2_INT_EXPORT_EXPTEXT_H

#include <vector>
#include <cstddef>
#include "int/export.h"

/** Export text table. This builds a table using ASCII characters. */
class IntTextExporter : public IntExporter {
    TextFile& tf;                      ///< Text file to write to.
    bool boxes;                        ///< true to create boxy table, false to create plain table.
    string_t line;                     ///< Current table line.
    int currentField;                  ///< Next field number.
    std::vector<std::size_t> widths;   ///< Field widths.
    int totalWidth;                    ///< Total width of table.
    int currentLine;                   ///< Current line number.

    void startLine();
    void addValue(string_t value, bool left);
    void endLine();
    void writeDivider();

 public:
    IntTextExporter(TextFile& tf, bool boxes);
    void startTable(const IntExportFieldList& fields, const TIntTypeHint types[]);
    void startRecord();
    void addField(IntValue* value, const string_t& name, TIntTypeHint type);
    void endRecord();
    void endTable();
};


#endif
