/**
  *  \file int/if/mapmsgif.cc
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/if/mapmsgif.h"
#include "game/msg.h"
#include "int/if/msgif.h"
#include "game/global.h"
#include "int/if/ifutil.h"
#include "int/interror.h"

namespace {
    class IntMappedMessageContext : public IntMessageContext {
     public:
        IntMappedMessageContext(GMessagebox& mbox, const std::vector<int>& nrs, int nr)
            : IntMessageContext(mbox, nr),
              nrs(nrs)
            { }

        int mapId(int nr)
            { return (nr >= 0 && nr < int(nrs.size())) ? nrs[nr] : -1; }

        virtual IntContext* clone()
            { return new IntMappedMessageContext(mbox, nrs, nr); }

     private:
        std::vector<int> nrs;
    };
}

IntMappedMessageValue::IntMappedMessageValue(const std::vector<int> nrs)
    : nrs(nrs)
{ }

// IntIndexableValue:
IntValue*
IntMappedMessageValue::get(IntArgBlock& args)
{
    args.checkArgumentCount(1);
    if (!haveDisplayedTurn()) {
        return 0;
    }

    int32_t n;
    if (!checkIntArg(n, args.getNext(), 1, nrs.size())) {
        return 0;
    }

    GMessagebox& inbox = getDisplayedTurn().getInbox();
    return new IntMappedMessageContext(inbox, nrs, n-1);
}

void
IntMappedMessageValue::set(IntArgBlock& /*args*/, IntValue* /*value*/)
{
    throw IntError::notAssignable();
}

int32_t
IntMappedMessageValue::getDimension(int32_t dim)
{
    if (!haveDisplayedTurn()) {
        return 0;
    } else if (dim == 0) {
        return 1;
    } else {
        return nrs.size()+1;
    }
}

IntContext*
IntMappedMessageValue::makeFirstContext()
{
    if (nrs.empty() || !haveDisplayedTurn()) {
        return 0;
    }
    GMessagebox& inbox = getDisplayedTurn().getInbox();
    return new IntMappedMessageContext(inbox, nrs, 0);
}

// IntValue:
IntMappedMessageValue*
IntMappedMessageValue::clone()
{
    // This copies the vector.
    // Since the vectors are short, this is acceptable and simpler than some reference counting scheme.
    return new IntMappedMessageValue(nrs);
}

string_t
IntMappedMessageValue::toString(bool /*readable*/)
{
    return "#<array>";
}

void
IntMappedMessageValue::store(IntTagNode& /*sv*/, Stream& /*aux*/)
{
    throw IntError::notSerializable();
}

IntMappedMessageValue*
IntMappedMessageValue::create(const std::vector<int> nrs)
{
    // We want "If Messages Then..." to be a valid test.
    // Therefore, instead of an empty array, return null.
    if (nrs.empty()) {
        return 0;
    } else {
        return new IntMappedMessageValue(nrs);
    }
}
