/**
  *  \file io/nullstream.cc
  *  \brief Null stream (data sink)
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "io/nullstream.h"

/** Constructor. */
NullStream::NullStream()
    : pos(0), size(0)
{ }

/** Destructor. */
NullStream::~NullStream()
{ }

std::size_t
NullStream::read(char* buffer, std::size_t nbytes)
{
    (void) buffer;
    (void) nbytes;
    return 0;
}

std::size_t
NullStream::write(const char* buffer, std::size_t nbytes)
{
    (void) buffer;
    pos += nbytes;
    if (pos > size)
        size = pos;
    return nbytes;
}

int
NullStream::getCapabilities() const
{
    return C_WRITE | C_SEEK;
}

void
NullStream::seek(fpos_t pos)
{
    this->pos = pos;
}

NullStream::fpos_t
NullStream::getSize()
{
    return size;
}

NullStream::fpos_t
NullStream::getPos()
{
    return pos;
}

string_t
NullStream::getName()
{
    return "<null>";
}
